;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "dired-video-thumbnail" "20251215.816"
  "Display video thumbnails from dired."
  '((emacs "28.1"))
  :url "https://github.com/captainflasmr/dired-video-thumbnail"
  :commit "4735c6d81c48228f9dccc48a09ca715bf2e6ffad"
  :revdesc "4735c6d81c48"
  :keywords '("multimedia" "files" "dired"))
